## FastFlyer: 轻量级 API 开发框架

## 项目介绍
本项目基于 FastFlyer 开发框架，用于 XXXX 场景。首次参与开发请仔细阅读下文。

## 项目介绍
FastFlyer 是基于 FastAPI 设计的轻量级 API 开发框架。在 FastAPI 优异特性的基础上集成了一系列开箱即用的组件，包括Redis、MySQL、Kafka等。采用 SDK 接入方式，内置脚手架代码生成等辅助工具，让研发人员只需要专注于业务逻辑的实现，真正开箱即用！

注：更多框架介绍请阅读：[FastFlyer](https://github.com/jagerzhang/fastflyer)

![FastFlyer](logo.png)

## 正式开发
初次上手，请仔细阅读FastFlyer说明文档：[正式开发](https://github.com/jagerzhang/fastflyer#正式开发)

## 环境变量
项目支持通过七彩石或环境变量来修改各种配置，优先级上七彩石 > 环境变量，详细参数说明请阅读FastFlyer说明文档：[环境变量](https://github.com/jagerzhang/fastflyer#环境变量)

## 如何加入
PR is welcome!
